

CREATE OR REPLACE PROCEDURE SET_XACT_FRAUD_FLAG_RUX (
    I_USER_NAME            IN  VARCHAR2,
    I_FRAUD_IND             IN  VARCHAR2,
    I_CMX_TRAN_ID         IN  NUMBER,    
    I_SMH_ACCT_TYPE          IN  VARCHAR2,
    I_SMH_ACTIVITY_TYPE     IN  VARCHAR2,
    I_ALERT_TYPE         IN  VARCHAR2 ,
    I_RUX_NUMERIC_001    IN    NUMBER      ,
    I_RUX_NUMERIC_002    IN    NUMBER      ,
    I_RUX_NUMERIC_003    IN    NUMBER      ,
    I_RUX_NUMERIC_004    IN    NUMBER      ,
    I_RUX_NUMERIC_005    IN    NUMBER      ,
    I_RUX_IND_001         IN   VARCHAR2,
    I_RUX_IND_002        IN    VARCHAR2,
    I_RUX_IND_003        IN    VARCHAR2,
    I_RUX_IND_004        IN    VARCHAR2,
    I_RUX_IND_005        IN    VARCHAR2,
    I_RUX_4BYTE_STRING_001 IN  VARCHAR2,
    I_RUX_4BYTE_STRING_002 IN  VARCHAR2,
    I_RUX_4BYTE_STRING_003  IN VARCHAR2,
    I_RUX_4BYTE_STRING_004 IN  VARCHAR2,
    I_RUX_4BYTE_STRING_005  IN VARCHAR2,
    I_RUX_8BYTE_STRING_001  IN VARCHAR2,
    I_RUX_8BYTE_STRING_002  IN VARCHAR2,
    I_RUX_30BYTE_STRING_001 IN VARCHAR2 ,
     I_RUX_30BYTE_STRING_002 IN VARCHAR2 ,
     O_SQLCODE        OUT      INTEGER,
     O_SQLSTATE        OUT      VARCHAR2,
     O_SQLMSG          OUT     VARCHAR2 )
IS
-- #######################################################################################
--
-- FILE: SET_XACT_FRAUD_FLAG.SQL
--
--
-- DESCRIPTION:
--
-- Called By:
--
-- Calls:
--
-- HISTORY:
--    05/05/2011  leushe initial creation
--
-- NOTES:
--
--
-- USAGE:
--
--
-- TIPS:
--
-- #######################################################################################



-- STEP 0A. DECLARE  PROCEDURE VARIABLES
     l_sqlStmt varchar(1000);
     l_tabname varchar(100);
     L_ROWCOUNT INTEGER DEFAULT -1;

     L_ALERT_TYPE CHAR(1);
     L_SMH_ACCT_TYPE CHAR(2);
     L_SMH_ACTIVITY_TYPE CHAR(2);
    

     
BEGIN
     L_ALERT_TYPE := upper(I_ALERT_TYPE);
     L_SMH_ACTIVITY_TYPE := upper(I_SMH_ACTIVITY_TYPE);
     L_SMH_ACCT_TYPE := upper(I_SMH_ACCT_TYPE);


--Find the table name for the account and activity provided.
select rh_table_name into l_tabname from (select a.rh_table_name
from FRH_TRANSACTION_DEFINITION a, 
    FRH_TRANSACTION_COMPONENT b,    
    FRH_COMPONENT_VALUE c,     
    FRH_FIELD_DEFINITION e
where a.transaction_id = b.transaction_id
and b.component_Value_id = c.component_value_id
and e.field_name = 'smh_acct_type'
  and c.COMPONENT_VALUE  = L_SMH_ACCT_TYPE
  and c.component_field_id = e.field_id
INTERSECT
select a.rh_table_name
from FRH_TRANSACTION_DEFINITION a, 
    FRH_TRANSACTION_COMPONENT b,    
    FRH_COMPONENT_VALUE c,     
    FRH_FIELD_DEFINITION e
where a.transaction_id = b.transaction_id
and b.component_Value_id = c.component_value_id
and e.field_name = 'smh_activity_type'
  and c.COMPONENT_VALUE  = L_SMH_ACTIVITY_TYPE
  and c.component_field_id = e.field_id) t;
     
L_ROWCOUNT := SQL%ROWCOUNT;
IF ( L_ROWCOUNT  <> 1 ) THEN
       ROLLBACK;
        O_SQLCODE := -1;
        O_SQLSTATE := 'ERROR';
        O_SQLMSG := 'Tablename not found based on SMH_ACTIVITY_TYPE and SMH_ACCT_TYPE parameters passed in.';
       RETURN;
END IF;

--select alert_type from frh_alert_type_dim
select alert_type into l_alert_Type from frh_alert_Type_dim where alert_type = l_alert_Type;
L_ROWCOUNT := SQL%ROWCOUNT;
IF ( L_ROWCOUNT  <> 1 ) THEN
       ROLLBACK;
        O_SQLCODE := -1;
        O_SQLSTATE := 'ERROR';
        O_SQLMSG := 'Alert Type parameter not valid';
       RETURN;
END IF;

  l_sqlStmt :=
         'update '||l_tabname|| ' SET CMX_USER_FRAUD_'||L_ALERT_TYPE||'_IND =  '''||I_FRAUD_IND||''', CMX_USER_FRAUD_'||L_ALERT_TYPE
             ||'_TIMESTAMP = SYS_EXTRACT_UTC(CURRENT_TIMESTAMP), RHX_LSTUPDT_USER = '''||rtrim(I_USER_NAME)||''', RHX_LSTUPDT_TIMESTAMP = SYS_EXTRACT_UTC(CURRENT_TIMESTAMP) '
             ||', RUX_NUMERIC_001        = :1 '
             ||', RUX_NUMERIC_002        = :2 '
             ||', RUX_NUMERIC_003        = :3 '
             ||', RUX_NUMERIC_004        = :4 '
             ||', RUX_NUMERIC_005        = :5 '
             ||', RUX_IND_001            = :6 '
             ||', RUX_IND_002            = :7 '
             ||', RUX_IND_003            = :8 '
             ||', RUX_IND_004            = :9 '
             ||', RUX_IND_005            = :10 '
             ||', RUX_4BYTE_STRING_001   = :11 '
             ||', RUX_4BYTE_STRING_002   = :12 '
             ||', RUX_4BYTE_STRING_003   = :13 '
             ||', RUX_4BYTE_STRING_004   = :14 '
             ||', RUX_4BYTE_STRING_005   = :15 '
             ||', RUX_8BYTE_STRING_001   = :16 '
             ||', RUX_8BYTE_STRING_002   = :17 '
             ||', RUX_30BYTE_STRING_001  = :18 '
             ||', RUX_30BYTE_STRING_002  = :19 '
              ||' WHERE SMH_ACCT_TYPE = :20 AND SMH_ACTIVITY_TYPE = :21 AND  CMX_TRAN_ID = :22 ' ;
             

 --     DBMS_OUTPUT.put_line(l_sqlStmt); 
       EXECUTE immediate l_sqlStmt 
       USING 
                     I_RUX_NUMERIC_001,
                     I_RUX_NUMERIC_002,
                     I_RUX_NUMERIC_003,
                     I_RUX_NUMERIC_004,
                     I_RUX_NUMERIC_005,
                     I_RUX_IND_001,
                     I_RUX_IND_002,
                     I_RUX_IND_003,
                     I_RUX_IND_004,
                     I_RUX_IND_005,
                     I_RUX_4BYTE_STRING_001,
                     I_RUX_4BYTE_STRING_002,
                     I_RUX_4BYTE_STRING_003,
                     I_RUX_4BYTE_STRING_004,
                     I_RUX_4BYTE_STRING_005,
                     I_RUX_8BYTE_STRING_001,
                     I_RUX_8BYTE_STRING_002,
                     I_RUX_30BYTE_STRING_001,
                     I_RUX_30BYTE_STRING_002,
                     L_SMH_ACCT_TYPE,
                     L_SMH_ACTIVITY_TYPE,
                     I_CMX_TRAN_ID;

         O_SQLCODE := SQLCODE;
         O_SQLSTATE:='';
         O_SQLMSG := SUBSTR(SQLERRM, 1 , 1000);

  L_ROWCOUNT := SQL%ROWCOUNT;
  IF ( L_ROWCOUNT = 0 ) THEN
       ROLLBACK;
        O_SQLCODE := -1;
        O_SQLSTATE := 'NTFND';
        O_SQLMSG := 'Transaction Not Found';
       RETURN;
  END IF;
   
   
  
 COMMIT;


END SET_XACT_FRAUD_FLAG_RUX;
/
show errors;

